### Fix
* Made commit author consistent ([#917](https://github.com/amundsen-io/amundsenfrontendlibrary/issues/917)) ([`48441cd`](https://github.com/amundsen-io/amundsenfrontendlibrary/commit/48441cd3c073c7a68145fa329ea35ad125707d4d))
* Yaml syntax error ([#913](https://github.com/amundsen-io/amundsenfrontendlibrary/issues/913)) ([`8f49627`](https://github.com/amundsen-io/amundsenfrontendlibrary/commit/8f496279c5835f59cd120d23b589a9cd708d536d))
* Add chore to monthly release PRs ([#912](https://github.com/amundsen-io/amundsenfrontendlibrary/issues/912)) ([`9323862`](https://github.com/amundsen-io/amundsenfrontendlibrary/commit/93238628029a439d10a68398bcda19bb2992b945))
* Removed echo for changelog command ([#910](https://github.com/amundsen-io/amundsenfrontendlibrary/issues/910)) ([`bb22d4d`](https://github.com/amundsen-io/amundsenfrontendlibrary/commit/bb22d4d2babc015752c2dd38d3a3c380ab62473e))
* Add changelog file ([#907](https://github.com/amundsen-io/amundsenfrontendlibrary/issues/907)) ([`f06c50e`](https://github.com/amundsen-io/amundsenfrontendlibrary/commit/f06c50e03372a76472e523d222cc14db553f8fee))
* Made change to preserve format of changelog ([#896](https://github.com/amundsen-io/amundsenfrontendlibrary/issues/896)) ([`0d56d72`](https://github.com/amundsen-io/amundsenfrontendlibrary/commit/0d56d7228c4bd5e4a484e896390f322a77704f11))
* Fixed reviewers field syntax error ([#892](https://github.com/amundsen-io/amundsenfrontendlibrary/issues/892)) ([`b7f99d4`](https://github.com/amundsen-io/amundsenfrontendlibrary/commit/b7f99d4abef2c8468550b151678cfa1b317d35d6))
* Made branch eval and added reviewers ([#891](https://github.com/amundsen-io/amundsenfrontendlibrary/issues/891)) ([`dd57d44`](https://github.com/amundsen-io/amundsenfrontendlibrary/commit/dd57d445f3e76d2deb558df67a62e1fbcb1826df))
* Changed release workflow completely ([#882](https://github.com/amundsen-io/amundsenfrontendlibrary/issues/882)) ([`5dfcd09`](https://github.com/amundsen-io/amundsenfrontendlibrary/commit/5dfcd09feb6b28d4fa2921ed21d545b319e46e95))
* Index tag info into elasticsearch immediately after ui change ([#883](https://github.com/amundsen-io/amundsenfrontendlibrary/issues/883)) ([`b34151c`](https://github.com/amundsen-io/amundsenfrontendlibrary/commit/b34151c3b989246513c1a0c0030d0193fefee962))
